log using "C:\BLNContractFarming.smcl", replace

clear
clear matrix
drop _all
set mem 512m

use "C:\BLNContractFarming.dta", clear

drop cf_individuals cf_crops cf_plot_share cf_crop_share

drop _merge
sort codemen
merge codemen using "C:\prop_fixed_price.dta"

label variable soudure "Duration of Hungry Season"
label variable cf "Contract Farming Participant"
label variable hhsize "Household Size"
label variable depr "Dependency Ratio"
label variable female "Female"
label variable migrant "Migrant"
label variable age "Age"
label variable educ "Education"
label variable ag_exp "Agricultural Experience"
label variable fady "Fady Days"
label variable wrk_cap "Working Capital" 
label variable assets "Assets"
label variable k1_0 "No Any Investment"
label variable k1_1 "Yes to $12.50 Investment"
label variable k1_2 "Yes to $25.00 Investment"
label variable k1_3 "Yes to $37.50 Investment"
label variable k1_4 "Yes to $50.00 Investment"
label variable k1_5 "Yes to $62.50 Investment"
label variable k1_6 "Yes to $75.00 Investment"

drop if age==. | wrk_cap==.

count

replace k1_1 = 1 if (k1_2 == 1 | k1_3 ==1 | k1_4 == 1 | k1_5 == 1 | k1_6 == 1)
replace k1_2 = 1 if (k1_3 ==1 | k1_4 == 1 | k1_5 == 1 | k1_6 == 1)
replace k1_3 = 1 if (k1_4 == 1 | k1_5 == 1 | k1_6 == 1)
replace k1_4 = 1 if (k1_5 == 1 | k1_6 == 1)
replace k1_5 = 1 if (k1_6 == 1)




* Table 1 *

outreg2 using c:\data\cf_iv_t1, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): mean income income_pc income_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 if cf==0 [pweight=weight]
outreg2 using c:\data\cf_iv_t1, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): mean income income_pc income_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 if cf==1 [pweight=weight]


foreach i in income income_pc income_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2 fiv_3 fiv_4 fiv_5 fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 {

* `i' *
ttest `i', by(cf)

}


* Hausman Tests *

quietly: reg ln_income cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6
quietly: est store A

quietly: reg ln_income cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6
quietly: est store B

hausman A B


quietly: reg ln_income_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6
quietly: est store C

quietly: reg ln_income_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6
quietly: est store D

hausman C D


quietly: reg ln_income_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6
quietly: est store E

quietly: reg ln_income_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6
quietly: est store F

hausman E F


* CF does Not Appear Endogenous to Income; We Still Proceed by Including the WTP Variables Throughout


* Data Management *

* Table 2 *

outreg2 using c:\data\cf_iv_t2, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): reg ln_income cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)

quietly: reg ln_income cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)
quietly: predict u, resid
quietly: gen income_var_u = u^2
quietly: drop u


outreg2 using c:\data\cf_iv_t2, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): reg ln_income_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)

quietly: reg ln_income_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)
quietly: predict u, resid
quietly: gen income_var_u_pc = u^2
quietly: drop u


outreg2 using c:\data\cf_iv_t2, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): reg ln_income_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)

quietly: reg ln_income_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)
quietly: predict u, resid
quietly: gen income_var_u_ae = u^2
quietly: drop u


quietly: label variable income_var_u "Income Variability (Conditional Heteroskedasticity)"
quietly: label variable income_var_u_pc "Income Per Capita Variability (Conditional Heteroskedasticity)"
quietly: label variable income_var_u_ae "Income Per AE Variability (Conditional Heteroskedasticity)"

* Hausman Tests *

quietly: reg income_var_u cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6
quietly: est store G

quietly: reg income_var_u cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6
quietly: est store H

hausman G H


quietly: reg income_var_u_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6
quietly: est store I

quietly: reg income_var_u_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6
quietly: est store J

hausman I J


quietly: reg income_var_u_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6
quietly: est store K

quietly: reg income_var_u_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6
quietly: est store L

hausman K L


* Figure A1 *

kdensity income_var_u if cf==0, w(1) epanechnikov addplot(kdensity income_var_u, w(1) epanechnikov lpattern(dash)) title(Distribution of Income Variability) subtitle(Conditional Heteroskedasticity) legend(label(1 "Does Not Participate in CF")) legend(label(2 "Participates in CF")) graphregion(color(white)) bgcolor(white)
more


* Figure 1 *

kdensity income_var_u_pc if cf==0, w(1) epanechnikov addplot(kdensity income_var_u_pc, w(1) epanechnikov lpattern(dash)) title(Distribution of Income Per Capita Variability) subtitle(Conditional Heteroskedasticity) legend(label(1 "Does Not Participate in CF")) legend(label(2 "Participates in CF")) graphregion(color(white)) bgcolor(white)
more


* Figure A2 *

kdensity income_var_u_ae if cf==0, w(1) epanechnikov addplot(kdensity income_var_u_ae, w(1) epanechnikov lpattern(dash)) title(Distribution of Income Per AE Variability) subtitle(Conditional Heteroskedasticity) legend(label(1 "Does Not Participate in CF")) legend(label(2 "Participates in CF")) graphregion(color(white)) bgcolor(white)
more

* Unconditional Heteroskedasticity *

ttest income_var_u, by(cf)
ttest income_var_u_pc, by(cf)
ttest income_var_u_ae, by(cf)


* Conditional Heteroskedasticity *

* Table 3 *

quietly: egen income_var_u_std = std(income_var_u)
quietly: label variable income_var_u_std "Income Variability 1 (Standardized)"


outreg2 using c:\data\cf_iv_t3, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: reg income_var_u_std cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)
xi: reg income_var_u_std cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)
test k1_1 k1_2 k1_3 k1_4 k1_5 k1_6
boottest cf, weight(webb) level(90)
boottest cf, weight(webb) level(95)
boottest cf, weight(webb) level(99)

replace prop_fixed_price = 0 if prop_fixed_price==.
gen ytilde=.

capture program drop deboot
program define deboot, rclass
#delimit ;
regress income_var_u_std prop_fixed_price cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv);
replace ytilde = income_var_u_std - _b[prop_fixed_price]*prop_fixed_price;
regress ytilde cf single female migrant age educ ag_exp farm_org fady fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv);
return scalar deffect = _b[cf];
#delimit cr
end
bootstrap deffect = r(deffect), reps(500) seed(123456789): deboot


quietly: egen income_var_u_std_pc = std(income_var_u_pc)
quietly: label variable income_var_u_std_pc "Income Per Capita Variability 1 (Standardized)"


outreg2 using c:\data\cf_iv_t3, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: reg income_var_u_std_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)
xi: reg income_var_u_std_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)
test k1_1 k1_2 k1_3 k1_4 k1_5 k1_6
boottest cf, weight(webb) level(90)
boottest cf, weight(webb) level(95)
boottest cf, weight(webb) level(99)

drop ytilde
replace prop_fixed_price = 0 if prop_fixed_price==.
gen ytilde=.

capture program drop deboot
program define deboot, rclass
#delimit ;
regress income_var_u_std_pc prop_fixed_price cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv);
replace ytilde = income_var_u_std_pc - _b[prop_fixed_price]*prop_fixed_price;
regress ytilde cf single female migrant age educ ag_exp farm_org fady fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv);
return scalar deffect = _b[cf];
#delimit cr
end
bootstrap deffect = r(deffect), reps(500) seed(123456789): deboot


quietly: egen income_var_u_std_ae = std(income_var_u_ae)
quietly: label variable income_var_u_std_ae "Income Per AE Variability 1 (Standardized)"


outreg2 using c:\data\cf_iv_t3, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: reg income_var_u_std_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)
xi: reg income_var_u_std_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)
test k1_1 k1_2 k1_3 k1_4 k1_5 k1_6
boottest cf, weight(webb) level(90)
boottest cf, weight(webb) level(95)
boottest cf, weight(webb) level(99)

drop ytilde
replace prop_fixed_price = 0 if prop_fixed_price==.
gen ytilde=.

capture program drop deboot
program define deboot, rclass
#delimit ;
regress income_var_u_std_ae prop_fixed_price cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv);
replace ytilde = income_var_u_std_ae - _b[prop_fixed_price]*prop_fixed_price;
regress ytilde cf single female migrant age educ ag_exp fady fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv);
return scalar deffect = _b[cf];
#delimit cr
end
bootstrap deffect = r(deffect), reps(500) seed(123456789): deboot


* Robustness: Median Regression *

* Conditional Heteroskedasticity *

* Table A1 *

quietly: outreg2 using c:\data\cf_iv_tA1, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: qreg income_var_u_std cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight]
xi: qreg income_var_u_std cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight]
boottest cf, weight(webb) level(90)
boottest cf, weight(webb) level(95)
boottest cf, weight(webb) level(99)

quietly: outreg2 using c:\data\cf_iv_tA1, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: qreg income_var_u_std_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight]
xi: qreg income_var_u_std_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight]
boottest cf, weight(webb) level(90)
boottest cf, weight(webb) level(95)
boottest cf, weight(webb) level(99)

quietly: outreg2 using c:\data\cf_iv_tA1, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: qreg income_var_u_std_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight]
xi: qreg income_var_u_std_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight]
boottest cf, weight(webb) level(90)
boottest cf, weight(webb) level(95)
boottest cf, weight(webb) level(99)



* Conditional Heteroskedasticity for Proportion of Fixed Price Contracts *

* Table 4 *

quietly: outreg2 using c:\data\cf_iv_t4, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: reg income_var_u_std prop_fixed_price hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)
xi: reg income_var_u_std prop_fixed_price hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)
boottest prop_fixed_price, weight(webb) level(90)
boottest prop_fixed_price, weight(webb) level(95)
boottest prop_fixed_price, weight(webb) level(99)

quietly: outreg2 using c:\data\cf_iv_t4, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: reg income_var_u_std_pc prop_fixed_price hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)
xi: reg income_var_u_std_pc prop_fixed_price hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)
boottest prop_fixed_price, weight(webb) level(90)
boottest prop_fixed_price, weight(webb) level(95)
boottest prop_fixed_price, weight(webb) level(99)

quietly: outreg2 using c:\data\cf_iv_t4, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: reg income_var_u_std_ae prop_fixed_price hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)
xi: reg income_var_u_std_ae prop_fixed_price hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight], cluster(id_fiv)
boottest prop_fixed_price, weight(webb) level(90)
boottest prop_fixed_price, weight(webb) level(95)
boottest prop_fixed_price, weight(webb) level(99)

* Propensity Score Matching Results *

* Table 5 *

quietly: outreg2 using c:\data\cf_iv_t5, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): probit cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight], cluster(id_fiv)
probit cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight], cluster(id_fiv)
predict propensity


* Treatment Effects *

* Three Nearest Neighbors and 0.01 Caliper *

* Table 6 *

outreg2 using c:\data\cf_iv_t6, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): psmatch2 cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6, out(income_var_u_std) n(3) ate cal(.01) ai(3)

outreg2 using c:\data\cf_iv_t6, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): psmatch2 cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6, out(income_var_u_std_pc) n(3) ate cal(.01) ai(3)

outreg2 using c:\data\cf_iv_t6, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): psmatch2 cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6, out(income_var_u_std_ae) n(3) ate cal(.01) ai(3)


* Three Nearest Neighbors and 0.01 Caliper *

* Table A2 *

quietly: drop propensity
outreg2 using c:\data\cf_iv_tA2, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): pstest hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_1-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6

quietly: probit cf hhsize depr single female migrant age educ ag_exp farm_org fady income wrk_cap assets land_tot fiv_2-fiv_6 k1_1-k1_6 [pweight=weight]
quietly: predict propensity

twoway hist propensity if cf==1, fcolor(none) lcolor(black) lpattern(solid) || hist propensity if cf==0, fcolor(none) lcolor(black) lpattern(shortdash) xtitle(Propensity Score) title(Distribution of Propensity Scores) legend(order(1 "CF Participant" 2 "CF Nonparticipant")) graphregion(color(white)) legend(off)


* Weighted Regression Estimators *
* Conditional Heteroskedasticity *

* Table 7 *

quietly: gen weight_ate = (1/propensity)*weight if cf==1
quietly: replace weight_ate = (1/(1-propensity))*weight if cf==0


quietly: gen weight_att = 1*weight if cf==1
quietly: replace weight_att = (propensity/(1-propensity))*weight if cf==0


quietly: gen weight_atu = ((1-propensity)/propensity)*weight if cf==1
quietly: replace weight_atu = 1*weight if cf==0



/* Doubly Robust Regressions */
/* ATEs */

quietly: outreg2 using c:\data\cf_iv_t7, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: reg income_var_u_std cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_ate]
xi: reg income_var_u_std cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_ate]
boottest cf, weight(webb) level(90)
boottest cf, weight(webb) level(95)
boottest cf, weight(webb) level(99)

quietly: outreg2 using c:\data\cf_iv_t7, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: reg income_var_u_std_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_ate]
xi: reg income_var_u_std_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_ate]
boottest cf, weight(webb) level(90)
boottest cf, weight(webb) level(95)
boottest cf, weight(webb) level(99)

quietly: outreg2 using c:\data\cf_iv_t7, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: reg income_var_u_std_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_ate]
xi: reg income_var_u_std_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_ate]
boottest cf, weight(webb) level(90)
boottest cf, weight(webb) level(95)
boottest cf, weight(webb) level(99)


/* ATTs */

quietly: outreg2 using c:\data\cf_iv_t7, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: reg income_var_u_std cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_att]
xi: reg income_var_u_std cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_att]
boottest cf, weight(webb) level(90)
boottest cf, weight(webb) level(95)
boottest cf, weight(webb) level(99)

quietly: outreg2 using c:\data\cf_iv_t7, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: reg income_var_u_std_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_att]
xi: reg income_var_u_std_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_att]
boottest cf, weight(webb) level(90)
boottest cf, weight(webb) level(95)
boottest cf, weight(webb) level(99)

quietly: outreg2 using c:\data\cf_iv_t7, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: reg income_var_u_std_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_att]
xi: reg income_var_u_std_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_att]
boottest cf, weight(webb) level(90)
boottest cf, weight(webb) level(95)
boottest cf, weight(webb) level(99)


/* ATUs */

quietly: outreg2 using c:\data\cf_iv_t7, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: reg income_var_u_std cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_atu]
xi: reg income_var_u_std cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_atu]
boottest cf, weight(webb) level(90)
boottest cf, weight(webb) level(95)
boottest cf, weight(webb) level(99)

quietly: outreg2 using c:\data\cf_iv_t7, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: reg income_var_u_std_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_atu]
xi: reg income_var_u_std_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_atu]
boottest cf, weight(webb) level(90)
boottest cf, weight(webb) level(95)
boottest cf, weight(webb) level(99)

quietly: outreg2 using c:\data\cf_iv_t7, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): xi: reg income_var_u_std_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_atu]
xi: reg income_var_u_std_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [pweight=weight_atu]
boottest cf, weight(webb) level(90)
boottest cf, weight(webb) level(95)
boottest cf, weight(webb) level(99)


* Table A3 *

*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
*****MLE estimation; joint estimation of income level and variance
* Western, Bruce, and Deirdre Bloome. "Variance function regressions for studying inequality." Sociological Methodology 39.1 (2009): 293-326.) 

*income
reg ln_income cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6, cluster(id_fiv)
predict R, r
* OLS resids;
gen R2 = R^2 
* squared resids for glm fit;
glm R2 cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6, cluster(id_fiv) family(gamma) link(log)
* gamma reg on log(r2);
predict S2, mu
* fitted variances, exp(Xb);
gen LOGLIK=-.5*(ln(S2)+(R2/S2))
* evaluating log likelihood;
egen LL0 = sum(LOGLIK)
* summing log likelihood;
di LL0
* Updating beta and lambda coefficients;
gen DLL=1
* initialize change in loglik;
while DLL > .00001 {
drop R
quietly: reg ln_income cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [aw=1/S2], cluster(id_fiv) 
* WLS with variances as weights;
drop S2
predict R, r
* WLS resids;
replace R2= R^2 
* squared resids for glm fit;
est store BETA
* saving beta coefs;
quietly:
glm R2 cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6, cluster(id_fiv) family(gamma) link(log)
* gamma reg on log(r2);
predict S2, mu
* fitted variances, exp(Xb);
est store LAMBDA
* saving lambda coefs;
replace LOGLIK=-.5*(ln(S2)+(R2/S2))
* evaluating log likelihood;
egen LLN = sum(LOGLIK)
* summing log likelihood;
di LLN
replace DLL=LLN-LL0
* assess convergence;
replace LL0=LLN
drop LLN
}
est table BETA LAMBDA, b se
* table with coefs and se’s
outreg2 using mle_tab, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): est table BETA LAMBDA, b se


*income per capita
reg ln_income_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6, cluster(id_fiv)
predict R_pc, r
* OLS resids;
gen R2_pc = (R_pc)^2 
* squared resids for glm fit;
glm R2_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6, cluster(id_fiv) family(gamma) link(log)
* gamma reg on log(r2);
predict S2_pc, mu
* fitted variances, exp(Xb);
gen LOGLIK_pc=-.5*(ln(S2_pc)+(R2_pc/S2_pc))
* evaluating log likelihood;
egen LL0_pc = sum(LOGLIK_pc)
* summing log likelihood;
di LL0_pc
* Updating beta and lambda coefficients;
gen DLL_pc =1
* initialize change in loglik;
while DLL_pc > .00001 {
drop R_pc
quietly: reg ln_income_pc  cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [aw=1/S2], cluster(id_fiv) 
* WLS with variances as weights;
drop S2_pc
predict R_pc, r
* WLS resids;
replace R2_pc= (R_pc)^2  
* squared resids for glm fit;
est store BETA_pc
* saving beta coefs;
quietly:
glm R2_pc cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6, cluster(id_fiv) family(gamma) link(log)
* gamma reg on log(r2);
predict S2_pc, mu
* fitted variances, exp(Xb);
est store LAMBDA_pc
* saving lambda coefs;
replace LOGLIK_pc=-.5*(ln(S2_pc)+(R2_pc/S2_pc))
* evaluating log likelihood;
egen LLN_pc = sum(LOGLIK_pc)
* summing log likelihood;
di LLN_pc
replace DLL_pc =LLN_pc-LL0_pc
* assess convergence;
replace LL0_pc = LLN_pc
drop LLN_pc
}
est table BETA_pc LAMBDA_pc, b se
* table with coefs and se’s
outreg2 using mle_tab, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): est table BETA_pc LAMBDA_pc, b se




*income per ae
reg ln_income_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6, cluster(id_fiv)
predict R_ae, r
* OLS resids;
gen R2_ae = (R_ae)^2 
* squared resids for glm fit;
glm R2_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6, cluster(id_fiv) family(gamma) link(log)
* gamma reg on log(r2);
predict S2_ae, mu
* fitted variances, exp(Xb);
gen LOGLIK_ae=-.5*(ln(S2_ae)+(R2_ae/S2_ae))
* evaluating log likelihood;
egen LL0_ae = sum(LOGLIK_ae)
* summing log likelihood;
di LL0_ae
* Updating beta and lambda coefficients;
gen DLL_ae =1
* initialize change in loglik;
while DLL_ae > .00001 {
drop R_ae
quietly: reg ln_income_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6 [aw=1/S2], cluster(id_fiv) 
* WLS with variances as weights;
drop S2_ae
predict R_ae, r
* WLS resids;
replace R2_ae= (R_ae)^2  
* squared resids for glm fit;
est store BETA_ae
* saving beta coefs;
quietly:
glm R2_ae cf hhsize depr single female migrant age educ ag_exp farm_org fady wrk_cap assets land_tot fiv_2-fiv_6 k1_1 k1_2 k1_3 k1_4 k1_5 k1_6, cluster(id_fiv) family(gamma) link(log)
* gamma reg on log(r2);
predict S2_ae, mu
* fitted variances, exp(Xb);
est store LAMBDA_ae
* saving lambda coefs;
replace LOGLIK_ae =-.5*(ln(S2_ae)+(R2_ae/S2_ae))
* evaluating log likelihood;
egen LLN_ae = sum(LOGLIK_ae)
* summing log likelihood;
di LLN_ae
replace DLL_ae =LLN_ae-LL0_ae
* assess convergence;
replace LL0_ae = LLN_ae
drop LLN_ae
}
est table BETA_ae LAMBDA_ae, b se
* table with coefs and se’s
outreg2 using mle_tab, se bdec(3) bfmt(fc) sdec(3) sfmt(fc) excel label slow(100): est table BETA_ae LAMBDA_ae, b se

log close
