
********************************************************************************
********************************************************************************
*"ERHS_Master_Final.dta" is identical to the "ERHS_Master.dta" generated from the Data Prep directory.

*This file generates (1) Conditional Heteroskedasticity ("income_var_u"), our cross-sectional proxy for household income variabitlity.
*This file generates (2) Household-level income variability over time ("income_var_time") (time-series measure of income variability within each household).
*This file generates the correlation coefficients between (1) and (2).
*This file generates Tables A4, A5, and A6 in the Appendix A.
  
********************************************************************************
********************************************************************************
clear
clear matrix 
clear mata 
set more off
set maxvar 8000

********************************************************************************
*ERHS_Master data is created from the Data_Prep do file under the Data Prep directory.

*Set your working directory here.
use "C:\Contract Farming paper\ERHS_replication\ERHS_Master_Final.dta" 

*generate income variation over time
egen var_time = std(ln_income), by (hhid)
gen income_var_time = var_time^2
label variable income_var_time "Income Variance over Time (Income)"
drop var_time


*generate cross-sectional income variation
set seed 43434
reg ln_income hhsize  single_head head_female dependency_ratio head_migrant farmer_head age_HHhead lsu plot_area prod_coop_exist i.pa, vce(bootstrap, reps(500)) 
predict u, resid
gen income_var_u = u^2
label variable income_var_u "Conditional Heteroskedasticity (Income)"


pwcorr  income_var_time income_var_u, sig

pwcorr  income_var_time income_var_u if round==1, sig
pwcorr  income_var_time income_var_u if round==2, sig
pwcorr  income_var_time income_var_u if round==3, sig
pwcorr  income_var_time income_var_u if round==4, sig
*All the correlation coefficients are significant at less than 1% level of significance.


*generate labels
label var income "Household Income (Birr)"
label var hhsize "Household Size (Individuals)"
label var dependency_ratio "Dependency Ratio (Proportion)"
label var single_head "Household Head Single (Dummy)"
label var head_female "Household Head Female (Dummy)"
label var head_migrant "Household Head Migrant (Dummy)"
label var farmer_head "Household Head Farmer (Dummy)"
label var age_HHhead "Household Head Age (Years)"
label var edu_never "HH Head Never Attended School (Dummy)"
label var attended_primary "HH Head Attended Primary (Dummy)"
label var attended_secondary "HH Head Attended Secondary (Dummy)"
label var attended_tertiary "HH Head Attended Tertiary (Dummy)"
label var prod_coop_exist "Farmer Coop in Community (Dummy)"
label var plot_area "Household Landholdings (Hectares)"
label var lsu "Livestock Holdings (TLU)"



***Table A4: Descriptive Statistics from ERHS Data
eststo clear
 
 reg income  hhsize dependency_ratio single_head  head_female head_migrant farmer_head age_HHhead edu_never attended_primary attended_secondary attended_tertiary   plot_area lsu if round==1
outreg2 using TableA4.tex, sum replace ///
	ctitle(1994a) label bdec(3) bfmt(fc) sdec(3) sfmt(fc) tex(frag pretty)
 reg income  hhsize dependency_ratio  head_migrant age_HHhead   plot_area lsu if round==2
outreg2 using TableA4.tex, sum append ///
	ctitle(1994b) label bdec(3) bfmt(fc) sdec(3) sfmt(fc) tex(frag pretty)
	 reg income  hhsize dependency_ratio  single_head head_female head_migrant age_HHhead plot_area lsu if round==3
outreg2 using TableA4.tex, sum append ///
	ctitle(1995) label bdec(3) bfmt(fc) sdec(3) sfmt(fc) tex(frag pretty)
	 reg income  hhsize dependency_ratio  single_head head_female head_migrant farmer_head age_HHhead  prod_coop_exist prod_coop_exist plot_area lsu if round==4
outreg2 using TableA4.tex, sum append ///
	ctitle(1997) label bdec(3) bfmt(fc) sdec(3) sfmt(fc) tex(frag pretty)	



***Table A5: Correlation coefficients 
estimates clear
estpost corr  income_var_time income_var_u if round==1
	matrix ERHS1994a = e(b)
	ereturn post ERHS1994a
	eststo ERHS1994a
estpost corr  income_var_time income_var_u if round==2
	matrix ERHS1994b = e(b)
	ereturn post ERHS1994b
	eststo ERHS1994b
estpost corr  income_var_time income_var_u if round==3
	matrix ERHS1995 = e(b)
	ereturn post ERHS1995
	eststo ERHS1995
estpost corr  income_var_time income_var_u if round==4
	matrix ERHS1997 = e(b)
	ereturn post ERHS1997
	eststo ERHS1997	

*Table
	esttab ERHS1994a ERHS1994b ERHS1995 ERHS1997 ///
	using TableA5.tex, replace ///
	nonumber mtitles noobs not label ///
	mtitle ("1994a" "1994b" "1995" "1997") ///
 
 
***Table A6: Correlation coefficients of subgroups


estimates clear
* female HH head, single HH head, HH head is migrant
	local vars single_head head_female farmer_head head_migrant edu_never 
	foreach v in `vars'{
	estpost corr income_var_time income_var_u if round==1 & `v'==1
		matrix u_`v'1 = e(b)
		ereturn post u_`v'1
		eststo u_`v'1
	estpost corr income_var_time income_var_u if round==1 & `v'==0
		matrix u_`v'0 = e(b)
		ereturn post u_`v'0
		eststo u_`v'0
	}


*HH size
	local v hhsize
	estpost corr income_var_time income_var_u if round==1 & hhsize<=6
		matrix u_`v'_small = e(b)
		ereturn post u_`v'_small
		eststo u_`v'_small
	estpost corr income_var_time income_var_u if round==1 & hhsize>6
		matrix u_`v'_large = e(b)
		ereturn post u_`v'_large
		eststo u_`v'_large
		
* High v. low dependency ratio 
	local v dependency_ratio
	estpost corr income_var_time income_var_u if round==1 & dependency_ratio<=0.5
		matrix u_`v'_small = e(b)
		ereturn post u_`v'_small
		eststo u_`v'_small
	estpost corr income_var_time income_var_u if round==1 & dependency_ratio>0.5
		matrix u_`v'_large = e(b)
		ereturn post u_`v'_large
		eststo u_`v'_large

*Age of hh head 
	local v age_HHhead
	estpost corr income_var_time income_var_u if round==1 & age_HHhead<=65
		matrix u_`v'_young = e(b)
		ereturn post u_`v'_young
		eststo u_`v'_young
	estpost corr income_var_time income_var_u if round==1 & age_HHhead>65
		matrix u_`v'_old = e(b)
		ereturn post u_`v'_old
		eststo u_`v'_old

		
*Plot size
egen median_plot = median(plot_area), by(round)

	local v plot_area
	estpost corr income_var_time income_var_u if round==1 & plot_area<=median_plot
		matrix u_`v'_small = e(b)
		ereturn post u_`v'_small
		eststo u_`v'_small
	estpost corr income_var_time income_var_u if round==1 & plot_area>median_plot
		matrix u_`v'_large = e(b)
		ereturn post u_`v'_large
		eststo u_`v'_large

*livestock holdings
egen median_lsu = median(lsu), by(round)

	local v lsu
	estpost corr income_var_time income_var_u if round==1 & lsu<=median_lsu
		matrix u_`v'_small = e(b)
		ereturn post u_`v'_small
		eststo u_`v'_small
	estpost corr income_var_time income_var_u if round==1 & lsu>median_lsu
		matrix u_`v'_large = e(b)
		ereturn post u_`v'_large
		eststo u_`v'_large		

		
		
*Table A6 -  subgroup analysis table
esttab u_hhsize* u_dependency_ratio* u_single_head* u_head_female* u_head_migrant* u_age_HHhead* u_edu_never* u_plot_area* u_lsu* ///
	using TableA6.tex, replace ///
	nonumber mtitles noobs not label 
	
	
