
********************************************************************************
********************************************************************************
*This file prepares the data to construct the ERHS_Master_Final.dta based on several data files.

*Raw data comes from Ethiopian Rural Household Surveys (ERHS), 1989-2009.

*For information on the ERHS, see: https://www.ifpri.org/publication/ethiopian-rural-household-surveys-erhs-1989-2009

*Data, questionnaires, and supporting documents downloadable at: https://dataverse.harvard.edu/dataset.xhtml?persistentId=hdl:1902.1/15646
 
********************************************************************************
********************************************************************************
clear
clear matrix 
clear mata 
set more off
set maxvar 8000

********************************************************************************
**************1994a Roster Data*************************************************
*This data file is identical to the file named "r1p1s1t4.tab", from ERHS 1994a Household module.

*Downloadable from: https://dataverse.harvard.edu/dataset.xhtml?persistentId=hdl:1902.1/15646

*From this round of survey, we obtain the variable on household's education level.
********************************************************************************

*Set your working directory here.
use "C:\ERHS_replication\Data Prep\ERHS_R1_Roster.dta" 

*generate round
gen round=1

*renaming some vars
ren q1a region
ren q1b woreda
ren q1c pa
ren q5 hhn

*create household ID
gen hhid=((region*10000)+(pa*100)+hhn)*100+woreda

sort hhid

*generate education dummies
gen  edu_never =0
replace edu_never =1 if q11_1b ==1 & q12_4==3
egen edu_never_r1 = max(edu_never), by(hhid)
drop edu_never 

*primary education or church education (religious/traditional education)
gen  attended_primary =0
replace attended_primary =1 if q11_1b ==1 & q12_5==2
replace attended_primary =1 if q11_1b ==1 & q12_5==3
replace attended_primary =1 if q11_1b ==1 & q12_5==4
egen attended_primary_r1 = max(attended_primary), by(hhid)
drop attended_primary 

gen  attended_secondary =0
replace attended_secondary =1 if q11_1b ==1 & q12_5==5
replace attended_secondary =1 if q11_1b ==1 & q12_5==6
egen attended_secondary_r1 = max(attended_secondary), by(hhid)
drop attended_secondary 

gen  attended_tertiary =0
replace attended_tertiary =1 if q11_1b ==1 & q12_5==7
egen attended_tertiary_r1 = max(attended_tertiary), by(hhid)
drop attended_tertiary 

keep hhid round   edu_never_r1 attended_primary_r1 attended_secondary_r1 attended_tertiary_r1

collapse (mean) round    edu_never_r1 attended_primary_r1 attended_secondary_r1 attended_tertiary_r1, by(hhid)

save "C:\ERHS_replication\Data Prep\ERHS_R1_Roster_modified.dta", replace


********************************************************************************
************Round 1234 Roster Data**********************************************
*This data file is identical to the file named "11 3.3.99 roster.tab", from ERHS 1997 Aggregates module.

*Downloadable from: https://dataverse.harvard.edu/dataset.xhtml?persistentId=hdl:1902.1/15646

*From this file, we obtain the variables on household composition and demographics.
********************************************************************************
************Round 1234 data
use  "C:\ERHS_replication\Data Prep\ERHS_R1234_Roster.dta" 
*renaming some vars
ren q1a region
ren q1b woreda
ren q1c pa
ren q1d hhn

*create household number
gen hhid=((region*10000)+(pa*100)+hhn)*100+woreda

gen children_old1 = 0
replace children_old1 = 1 if agernd1 < 15 | agernd1 >=65

gen adult1 = 0
replace adult1 = 1 if agernd1>=15 | agernd1<65

sort hhid
by hhid: egen num_dependent1 = total(children_old1)
by hhid: egen num_adult1 = total(adult1)
gen dependency_ratio1 = num_dependent1/num_adult1

gen children_old2 = 0
replace children_old2 = 1 if agernd2 < 15 | agernd2 >=65

gen adult2 = 0
replace adult2 = 1 if agernd2>=15 | agernd2<65

sort hhid
by hhid: egen num_dependent2 = total(children_old2)
by hhid: egen num_adult2 = total(adult2)
gen dependency_ratio2 = num_dependent2/num_adult2

gen children_old3 = 0
replace children_old3 = 1 if agernd3 < 15 | agernd3 >=65

gen adult3 = 0
replace adult3 = 1 if agernd3>=15 | agernd3<65

sort hhid
by hhid: egen num_dependent3 = total(children_old3)
by hhid: egen num_adult3 = total(adult3)
gen dependency_ratio3 = num_dependent3/num_adult3

gen children_old4 = 0
replace children_old4 = 1 if age4 < 15 | age4 >=65

gen adult4 = 0
replace adult4 = 1 if age4 >=15 | age4 <65

sort hhid
by hhid: egen num_dependent4 = total(children_old4)
by hhid: egen num_adult4 = total(adult4)
gen dependency_ratio4 = num_dependent4/num_adult4

*generate indicator for female HH head
tab q11_1b
gen female_head1 = 0
replace female_head1 = 1 if q11_1b==1 & q11_5==2
sort hhid
by hhid: egen head_female1 = max(female_head1)
gen head_female2 = head_female1

gen female_head3 = 0
replace female_head3 = 1 if reltn3==1 &  sex==2
sort hhid
by hhid: egen head_female3 = max(female_head3)

gen female_head4 = 0
replace female_head4 = 1 if reltn4==1 &  sex==2
sort hhid
by hhid: egen head_female4 = max(female_head4)

drop female_head1  female_head3 female_head4

*generate indicator for single HH head
gen spouse1 = 0
replace spouse1 = 1 if q11_1b==2
sort hhid
by hhid: egen spouse_r1 = max(spouse1)
gen single_head1 = 0
replace single_head1 = 1 if spouse_r1==0
drop spouse_r1 spouse1

gen single_head2 = single_head1

gen spouse3 = 0
replace spouse3 = 1 if reltn3==2
sort hhid
by hhid: egen spouse_r3 = max(spouse3)
gen single_head3 = 0
replace single_head3 = 1 if spouse_r3==0
drop spouse_r3 spouse3

gen spouse4 = 0
replace spouse4 = 1 if reltn4==2
sort hhid
by hhid: egen spouse_r4 = max(spouse4)
gen single_head4 = 0
replace single_head4 = 1 if spouse_r4==0
drop spouse_r4 spouse4

keep hhid dependency_ratio1 dependency_ratio2 dependency_ratio3 dependency_ratio4 head_female1 head_female2 head_female3 head_female4 single_head1 single_head2 single_head3 single_head4
collapse (mean) dependency_ratio1 dependency_ratio2 dependency_ratio3 dependency_ratio4  head_female1 head_female2 head_female3 head_female4 single_head1 single_head2 single_head3 single_head4 , by(hhid)

sort hhid
merge 1:1 hhid using ERHS_R1_Roster_modified
drop _merge
drop round 
ren edu_never_r1 edu_never1
ren attended_primary_r1 attended_primary1
ren attended_secondary_r1 attended_secondary1
ren attended_tertiary_r1 attended_tertiary1
gen edu_never2 = edu_never1
gen edu_never3 = edu_never1
gen edu_never4 = edu_never1
gen attended_primary2 = attended_primary1
gen attended_primary3 = attended_primary1
gen attended_primary4 = attended_primary1
gen attended_secondary2 = attended_secondary1
gen attended_secondary3 = attended_secondary1
gen attended_secondary4 = attended_secondary1
gen attended_tertiary2 = attended_tertiary1
gen attended_tertiary3 = attended_tertiary1
gen attended_tertiary4 = attended_tertiary1

reshape long dependency_ratio head_female single_head edu_never attended_primary attended_secondary attended_tertiary, i(hhid) j(round)  


save "C:\ERHS_replication\Data Prep\ERHS_R1234_Roster_modified.dta" , replace


********************************************************************************
******************Income and Migration******************************************
*From this file, we obtain the variables on household income, aseets, and migration in 1994a, 1994b, 1995, and 1997 ERHS rounds.
*This data file is compiled and constructed by authors from the original ERHS household, community, and aggregates modules, downloaded from: https://dataverse.harvard.edu/dataset.xhtml?persistentId=hdl:1902.1/15646

*Income variables are complied by Marc Bellemare, Chris Barrett, and David R. Just for the following paper:
*Marc F. Bellemare, Christopher B. Barrett, David R. Just, The Welfare Impacts of Commodity Price Volatility: Evidence from Rural Ethiopia, American Journal of Agricultural Economics, Volume 95, Issue 4, July 2013, Pages 877–899, https://doi.org/10.1093/ajae/aat018

*Migration-related variables are compiled by Yu Na Lee, for the following paper:
*Lee, Yu Na, Does an Aversion to Price Risk Drive Migration? Evidence from Rural Ethiopia, 2020, Working paper.

*The authors are available for further explanations on how the income and migration variables are constructed.

*Any inconsistency with respect to the original data is full responsability of the authors.
********************************************************************************
use "C:\ERHS_replication\Data Prep\ERHS_Migration.dta" 

*Delete outlier
drop if hhid == 4082708
drop if hhid == 4088708

*The ln_income is an inverse hyperbolic sine (IHS) transformation of total income of an average seasonal income (Birr), and contains labor income (both on-farm and off-farm, and both from wages and self-employment), crop sales,remittances, sales of assets, including livestock, and sales of animal products for each period.

*generate inverse hyperbolic sine (IHS) transformation of income, to address zero-valued incomes.
gen theta = 1
gen ln_income = theta*ln(theta*income + ((theta^2)*income^2 +1)^0.5)

keep hhid round pa woreda region hhsize age_HHhead income ln_income head_migrant farmer_head prod_coop_exist plot_area lsu assets

*merge with other files
merge 1:1 hhid round using ERHS_R1234_Roster_modified 


save "C:\ERHS_replication\ERHS_Master.dta", replace 
*This data is identical to ERHS_Master_Final data.