/*-----------------------------------------------------------------------------------------------------------------------------------------------------
The first three .do files are adapted from the files created by the Evans School Policy Analysis & Research Group (EPAR) at 
				  the University of Washington for the construction of a set of agricultural development indicators 
				  using the Tanzania National Panel Survey (TNPS-LSMS-ISA) Wave 1 (2008-09), Wave 2 (2010-11), and 
				  Wave 3 (2012-13). Wave 4 is not included because it is a panel refresh.

Authors of the original EPAR code: Didier Alia, Pierre Biscaye, David Coomes, Jack Knauer, Josh Merfeld,  
				  Isabella Sun, Chelsea Sweeney, Emma Weaver, Ayala Wineman, 
				  C. Leigh Anderson, &  Travis Reynolds

They acknowledge acknowledge the helpful contributions of members of the World Bank's LSMS-ISA team, the FAO's RuLIS team, IFPRI, IRRI, 
				  and the Bill & Melinda Gates Foundation Agricultural Development Data and Policy team in discussing indicator construction decisions. 
				  All coding errors remain ours alone.
				  
The code from EPAR adapted in these files are from  Version - 18 September 2019. 

This code was last updated on September 23, 2020 for Contract Farming as Partial Insurance (Bellemare, Lee, & Novak 2020) 
				published in World Development
----------------------------------------------------------------------------------------------------------------------------------------------------*/

*To use this code, you must download the raw Tanzania NPS data files from the LSMS website (see links below)


clear
global directory "SET WORKING DIRECTORY HERE"
	global code "$directory/Code"


/*This file cleans wave 1 of the NPS data. To run this file:
	a. Create a folder titled "Tanzania NPS Wave 1" within the $directory path 
	b. Within "Tanzania NPS Wave 1", create 2 folders
		1. "Raw DTA Files" where all raw data downloaded from the LSMS website 
			(http://microdata.worldbank.org/index.php/catalog/76) is included in 
			a folder titled "TZA_2008_NPS1_v02_M_STATA_English_labels"
		2. "Final DTA Files" where the cleaned files will be saved. Within
			this folder, there should be two sub-folders titled "created_data"
			and "final_data" */	
	do "$code/02 Tanzania_NPS_W1.do"

	
/*This file cleans wave 2 of the NPS data. To run this file:
	a. Create a folder titled "Tanzania NPS Wave 2" within the $directory path
	b. Within "Tanzania NPS Wave 2", create 2 folders
		1. "Raw DTA Files" where all raw data downloaded from the LSMS website 
			(http://microdata.worldbank.org/index.php/catalog/1050) is included in 
			a folder titled "TZA_2010_NPS-R2_v02_M_STATA8"
		2. "Final DTA Files" where the cleaned files will be saved. Within
			this folder, there should be two sub-folders titled "created_data"
			and "final_data" */	
	do "$code/03 Tanzania_NPS_W2.do"


/*This file cleans wave 3 of the NPS data. To run this file:
	a. Create a folder titled "Tanzania NPS Wave 3" within the $directory path
	b. Within "Tanzania NPS Wave 3", create 2 folders
		1. "Raw DTA Files" where all raw data downloaded from the LSMS website 
			(http://microdata.worldbank.org/index.php/catalog/2252) is included in 
			a folder titled "TZA_2012_NPS-R3_v01_M_STATA8_English_labels"
		2. "Final DTA Files" where the cleaned files will be saved. Within
			this folder, there should be two sub-folders titled "created_data"
			and "final_data" */	
	do "$code/04 Tanzania_NPS_W3.do"


/*This file merges the three waves of data and creates all tables in Appendix A.
	To run this file, you need a folder within the $directory path titled "Output"*/	
	do "$code/05 Analysis.do"

