clear	
set more off
clear matrix	
clear mata	
set maxvar 8000	
eststo clear

*Set location of raw data and output
global directory  "SET WORKING DIRECTORY HERE - Same path as in 01 Read Me.do"
	
	global wave1 "$directory/Tanzania NPS Wave 1/Final DTA Files/final_data"
	global wave2 "$directory/Tanzania NPS Wave 2/Final DTA Files/final_data"
	global wave3 "$directory/Tanzania NPS Wave 3/Final DTA Files/final_data"
	global output "$directory/Output"

use "$wave1/Tanzania_NPS_W1_household_variables.dta"
	merge 1:1 hhid_panel using "$wave2/Tanzania_NPS_W2_household_variables.dta", gen(merge_w2)
	merge 1:1 hhid_panel using "$wave3/Tanzania_NPS_W3_household_variables.dta", gen(merge_w3)

drop count
keep if rural==1 //Keep only households in rural areas

	

**Lowest income observation is -719. Use inverse hyperbolic sine instead of log income
local vars w_total_income_1ppp_w1 w_total_income_1ppp_w2 w_total_income_1ppp_w3
foreach v in `vars'{
	gen IHS_`v' = ln(`v' + ((`v'^2 +1)^0.5))
}


//Create measures of variation across 3 waves	
egen IHS_inc_sd=rowsd(IHS_w_total_income_1ppp_w1 IHS_w_total_income_1ppp_w2 IHS_w_total_income_1ppp_w3)
	replace IHS_inc_sd=. if IHS_w_total_income_1ppp_w1==. | IHS_w_total_income_1ppp_w2==. | IHS_w_total_income_1ppp_w3==.
gen IHS_inc_var=IHS_inc_sd^2
	label var IHS_inc_var "Intrahousehold Income Variation (USD 2016 PPP)"

//Include only households with income information in all three waves	
	replace IHS_w_total_income_1ppp_w1=. if IHS_inc_sd==.
	replace IHS_w_total_income_1ppp_w2=. if IHS_inc_sd==.
	replace IHS_w_total_income_1ppp_w3=. if IHS_inc_sd==.

	

//Clean and label variables

local wave w1 w2 w3
foreach w in `wave'{
	label variable w_total_income_1ppp_`w' "Household Income (USD 2016 PPP)" //w1, w2, w3
	label variable IHS_w_total_income_1ppp_`w' "IHS Household Income (USD 2016 PPP)" //w1, w2, w3
	label variable cf_`w' "Contract Farming Participant" //w1, w2, w3
	label variable hhsize_`w' "Household Size (Individuals)" //w1, w2, w3
	label variable depr_`w' "Dependency Ratio (Proportion)" //w1, w2, w3
	label variable single_`w' "Household Head Single (Dummy)" //ww1, w2, w3
	label variable female_`w' "Household Head Female (Dummy)" //w1, w2, w3
	label variable migrant_`w' "Household Head Migrant (Dummy)" //w1, w2, w3
	label variable age_`w' "Household Head Age (Years)" //w1, w2, w3
	label variable educ_`w' "Household Head Education (Level)" //w1, w2, w3
	label variable farm_org_`w' "Farmer Coop Exists in Community (Dummy)" //w1, w2, w3 --  They don't have if the farmer is a member, but they have # of farmers participating in village
	label variable farm_org_number_`w' "Participation in Farmer Coop in Community (Number of Farmers)"
	label variable land_tot_`w' "Household Landholdings (Hectares)" //w1, w2, w3

	recode educ_`w' (11 12 13 14 15 16 17 18 19=1) (20 21 22 23 24 25 = 2) (32 33 34 43 44 45=3) //Recode levels of education to none, primary, secondary, tertiary
	tab educ_`w', gen(educ_`w'_)
		label var educ_`w'_1 "Household Head Never Attended School (Dummy)"
		label var educ_`w'_2 "Household Head Attended Primary School (Dummy)"
		label var educ_`w'_3 "Household Head Attended Secondary School (Dummy)"
		label var educ_`w'_4 "Household Head Attended Tertiary Education (Dummy)"
}
	rename w_value_assets_w3 assets_w3
	label variable assets_w3 "Household Assets (USD 2016 PPP)" //w3 only

//Variables included in our Madagascar data but not in LSMS	
	*ag_exp "Agricultural Experience" //Nothing like this in LSMS data
	*fady "Fady Days" //Not applicable. No mention of any ag restrictions in LSMS
	*wrk_cap "Working Capital" //Not available in LSMS data

	
//Wave 1

//Rename variables in order to use the same code for each wave
local vars w_total_income_1ppp IHS_w_total_income_1ppp cf hhsize depr single female migrant age educ farm_org land_tot 
	foreach v in `vars'{
		rename `v'_w1 `v'
	}
	
		rename educ_w1_1 educ1
		rename educ_w1_2 educ2
		rename educ_w1_3 educ3
		rename educ_w1_4 educ4

recode farm_org (2=0)
replace farm_org_number_w1=0 if farm_org ==0


//Restrict the sample to those with no missing data in wave 1
reg IHS_inc_var w_total_income_1ppp  cf  hhsize  depr  single  female  migrant  age  educ1-educ4  farm_org  land_tot  i.region
	gen sample_w1=e(sample)

//Generate conditional heteroskedasticity measure for wave 1
reg IHS_w_total_income_1ppp  cf  hhsize  depr  single  female  migrant  age  educ1-educ4  farm_org  land_tot  i.region if sample_w1==1		
	predict u, resid
	gen income_var_u  = u^2
	label variable income_var_u  "Income Variability (Conditional Heteroskedasticity)"

// Table A1, column 1 -- Descriptive stats
reg w_total_income_1ppp  cf  hhsize  depr  single  female  migrant  age  educ1-educ4  farm_org  land_tot if sample_w1==1
outreg2 using "$output/TableA1DescriptiveStats.tex", sum replace ///
	ctitle(Wave 1) label bdec(3) bfmt(fc) sdec(3) sfmt(fc) tex(frag pretty)


	
//Table A2, column 1 - Correlation coefficients (Complete table is constructed at the end of the .do file)
estpost corr IHS_inc_var income_var_u if sample_w1==1
	matrix Wave1_u = e(b)
	ereturn post Wave1_u
	eststo Wave1_u


	
//////Table A3 - Subgroup analyses//////

	//Table A3 - All Binary Variables	
	local vars female cf single migrant educ1
	foreach v in `vars'{
	estpost corr IHS_inc_var income_var_u if sample_w1==1 & `v'==1
		matrix u_`v'1 = e(b)
		ereturn post u_`v'1
		eststo u_`v'1
	estpost corr IHS_inc_var income_var_u if sample_w1==1 & `v'==0
		matrix u_`v'0 = e(b)
		ereturn post u_`v'0
		eststo u_`v'0
	
	}
		

	//Table A3 - Large v. small hhouseholds
	local v hhsize
	estpost corr IHS_inc_var income_var_u if sample_w1==1 & inrange(hhsize,1,6)
		matrix u_`v'_small = e(b)
		ereturn post u_`v'_small
		eststo u_`v'_small
	estpost corr IHS_inc_var income_var_u if sample_w1==1 & inrange(hhsize,7,50)
		matrix u_`v'_large = e(b)
		ereturn post u_`v'_large
		eststo u_`v'_large
	
	
	//Table A3 - High v. low dependency ratio 
	local v depr
	estpost corr IHS_inc_var income_var_u if sample_w1==1 & inrange(depr,0,0.5)
		matrix u_`v'_small = e(b)
		ereturn post u_`v'_small
		eststo u_`v'_small
	estpost corr IHS_inc_var income_var_u if sample_w1==1 & inrange(depr,0.501,1)
		matrix u_`v'_large = e(b)
		ereturn post u_`v'_large
		eststo u_`v'_large
	
	
	//Table A3 - Landholdings
	local v land_tot
	estpost corr IHS_inc_var income_var_u if sample_w1==1 & inrange(land_tot,0,1.110573) //median of land holdings
		matrix u_`v'_small = e(b)
		ereturn post u_`v'_small
		eststo u_`v'_small
	estpost corr IHS_inc_var income_var_u if sample_w1==1 & inrange(land_tot,1.1106,500)
		matrix u_`v'_large = e(b)
		ereturn post u_`v'_large
		eststo u_`v'_large
		
	
	//Table A3 - Age of hh head 
	local v age
	estpost corr IHS_inc_var income_var_u if sample_w1==1 & inrange(age,0,65) //dependent cutoff
		matrix u_`v'_young = e(b)
		ereturn post u_`v'_young
		eststo u_`v'_young
	estpost corr IHS_inc_var income_var_u if sample_w1==1 & inrange(age,66,110)
		matrix u_`v'_old = e(b)
		ereturn post u_`v'_old
		eststo u_`v'_old
	
	
		
//Build Table A3 -  subgroup analysis table
esttab u_hhsize* u_depr* u_single* u_female* u_migrant* u_age* u_educ1* u_land_tot* u_cf* ///
	using "$output/TableA3SubGroupCorrCoeffs.tex", replace ///
	nonumber mtitles noobs not label 


//Rename variables to wave 1	
local vars w_total_income_1ppp IHS_w_total_income_1ppp income_var_u cf hhsize depr single female migrant age educ farm_org land_tot 
	foreach v in `vars'{
		rename `v' `v'_w1
	}
		rename  educ1 educ_w1_1
		rename  educ2 educ_w1_2
		rename  educ3 educ_w1_3
		rename  educ4 educ_w1_4

		drop u 


		
//Wave 2
local vars w_total_income_1ppp IHS_w_total_income_1ppp cf hhsize depr single female migrant age educ farm_org land_tot 
	foreach v in `vars'{
		rename `v'_w2 `v' 
	}
		rename educ_w2_1 educ1
		rename educ_w2_2 educ2
		rename educ_w2_3 educ3
		rename educ_w2_4 educ4

		replace farm_org_number_w2=0 if farm_org==0


//Restrict sample respondents with no missing data in wave 2	
reg IHS_inc_var IHS_w_total_income_1ppp cf hhsize depr single female migrant age educ1-educ4 farm_org land_tot i.region
	gen sample_w2=e(sample)

reg IHS_w_total_income_1ppp cf hhsize depr single female migrant age educ1-educ4 farm_org land_tot i.region if sample_w2==1
	predict u, resid
	gen income_var_u = u^2


//Table A1, column 2 - Descriptive statistics
reg w_total_income_1ppp cf hhsize depr single female migrant age educ1-educ4 farm_org land_tot if sample_w2==1
outreg2 using "$output/TableA1DescriptiveStats.tex", sum  ///
	ctitle(Wave 2) label bdec(3) bfmt(fc) sdec(3) sfmt(fc) tex(frag pretty)

	label variable income_var_u "Income Variability (Conditional Heteroskedasticity)"
	


//Table A2, column 2 - correlation coefficientss
estpost corr IHS_inc_var income_var_u 	if sample_w2==1
	matrix Wave2_u = e(b)
	ereturn post Wave2_u
	eststo Wave2_u
	

//Rename variables to wave 2	
local vars w_total_income_1ppp IHS_w_total_income_1ppp income_var_u cf hhsize depr single female migrant age educ farm_org land_tot 
	foreach v in `vars'{
		rename `v' `v'_w2
	}
	
		rename  educ1 educ_w2_1
		rename  educ2 educ_w2_2
		rename  educ3 educ_w2_3
		rename  educ4 educ_w2_4

	drop u 


	
	
	
//Wave 3
local vars w_total_income_1ppp IHS_w_total_income_1ppp cf hhsize depr single female migrant age educ farm_org land_tot 
	foreach v in `vars'{
		rename `v'_w3 `v'
	}
		rename educ_w3_1 educ1
		rename educ_w3_2 educ2
		rename educ_w3_3 educ3
		rename educ_w3_4 educ4

//Restrict sample to households with no missing data in wave 3
reg IHS_inc_var IHS_w_total_income_1ppp cf hhsize depr single female migrant age educ1-educ4 farm_org land_tot i.region assets 
	gen sample_w3=e(sample)

//Generate conditional heteroskedasticy measure
reg IHS_w_total_income_1ppp cf hhsize depr single female migrant age educ1-educ4 farm_org land_tot i.region assets if sample_w3==1
	predict u, resid
	gen income_var_u = u^2



//Table A1, column 3 - Descriptive Statistics
reg w_total_income_1ppp cf hhsize depr single female migrant age educ1-educ4 farm_org land_tot assets_w3 if sample_w3==1
outreg2 using "$output/TableA1DescriptiveStats.tex", sum  ///
	ctitle(Wave 3) label bdec(3) bfmt(fc) sdec(3) sfmt(fc) tex(frag pretty)

label variable income_var_u "Income Variability (Conditional Heteroskedasticity)"
	

//Table A2, column 3 - Correlation coefficients
estpost corr IHS_inc_var income_var_u	if sample_w3==1
	matrix Wave3_u = e(b)
	ereturn post Wave3_u
	eststo Wave3_u

	

//Rename variables to wave 3	
local vars w_total_income_1ppp IHS_w_total_income_1ppp income_var_u cf hhsize depr single female migrant age educ farm_org land_tot 
	foreach v in `vars'{
		rename `v' `v'_w3
	}	
		rename  educ1 educ_w3_1
		rename  educ2 educ_w3_2
		rename  educ3 educ_w3_3
		rename  educ4 educ_w3_4

	drop u 

	
//Table A2 - Build correlation coeff table 
esttab Wave1_u Wave2_u Wave3_u  ///
	using "$output/TableA2CorrCoefs.tex", replace ///
	nonumber mtitles noobs not label ///
	mtitle ("Wave 1" "Wave 2" "Wave 3")
 
